@@ -80,6 +80,7 @@ struct BrowseMainPagePrivate : public Ui_BrowseMainPage {
     FilterController *mFilterController = nullptr;
     QActionGroup *mSortAction = nullptr;
     KToggleAction *mSortDescendingAction = nullptr;
+    KToggleAction *mShowHiddenFilesAction = nullptr;
     QActionGroup *mThumbnailDetailsActionGroup = nullptr;
     PreviewItemDelegate *mDelegate = nullptr;
 
@@ -105,6 +106,10 @@ struct BrowseMainPagePrivate : public Ui_BrowseMainPage {
         mUrlNavigator = new KUrlNavigator(mFilePlacesModel, QUrl(), mUrlNavigatorContainer);
         mUrlNavigatorContainer->setAutoFillBackground(true);
         mUrlNavigatorContainer->setBackgroundRole(QPalette::Mid);
+        mUrlNavigatorContainer->setContentsMargins(mUrlNavigator->style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
+                                                   mUrlNavigator->style()->pixelMetric(QStyle::PM_LayoutTopMargin),
+                                                   mUrlNavigator->style()->pixelMetric(QStyle::PM_LayoutRightMargin),
+                                                   mUrlNavigator->style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
         auto layout = new QVBoxLayout(mUrlNavigatorContainer);
         layout->setContentsMargins(0, 0, 0, 0);
         layout->addWidget(mUrlNavigator);
@@ -191,6 +196,12 @@ struct BrowseMainPagePrivate : public Ui_BrowseMainPage {
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
         thumbnailDetailsAction->addAction(thumbnailDetailAction(i18nc("@action:inmenu", "Rating"), PreviewItemDelegate::RatingDetail));
 #endif
+        mShowHiddenFilesAction = view->add<KToggleAction>(QStringLiteral("view_toggle_showhiddenfiles"));
+        mShowHiddenFilesAction->setText(i18nc("@action:inmenu View", "Show Hidden Files"));
+        mShowHiddenFilesAction->setIcon(QIcon::fromTheme(QStringLiteral("view-visible")));
+        mShowHiddenFilesAction->setChecked(mDirModel->isShowHiddenFiles());
+        actionCollection->setDefaultShortcuts(mShowHiddenFilesAction, KStandardShortcut::showHideHiddenFiles());
+        QObject::connect(mShowHiddenFilesAction, SIGNAL(toggled(bool)), q, SLOT(slotToggleShowHiddenFiles()));
 
         auto file = new KActionCategory(i18nc("@title actions category", "File"), actionCollection);
         action = file->addAction(QStringLiteral("add_folder_to_places"), q, SLOT(addFolderToPlaces()));
@@ -369,6 +380,7 @@ void BrowseMainPage::loadConfig()
         }
     }
     d->mSortDescendingAction->setChecked(GwenviewConfig::sortDescending());
+    d->mShowHiddenFilesAction->setChecked(GwenviewConfig::showHiddenFiles());
 
     d->updateContextBarActions();
 }
@@ -381,6 +393,7 @@ void BrowseMainPage::saveConfig() const
     GwenviewConfig::setSorting(sortingFromSortAction(d->mSortAction->checkedAction()));
     GwenviewConfig::setSortDescending(d->mSortDescendingAction->isChecked());
     GwenviewConfig::setThumbnailDetails(d->mDelegate->thumbnailDetails());
+    GwenviewConfig::setShowHiddenFiles(d->mShowHiddenFilesAction->isChecked());
 }
 
 bool BrowseMainPage::eventFilter(QObject *watched, QEvent *event)
@@ -417,6 +430,11 @@ KUrlNavigator *BrowseMainPage::urlNavigator() const
     return d->mUrlNavigator;
 }
 
+void BrowseMainPage::slotToggleShowHiddenFiles()
+{
+    d->mDirModel->setShowHiddenFiles(d->mShowHiddenFilesAction->isChecked());
+}
+
 void BrowseMainPage::reload()
 {
     const QModelIndexList list = d->mThumbnailView->selectionModel()->selectedIndexes();
